@@ -67,11 +67,11 @@ class TestImage(IntegrationTestCase):
         super(TestImage, self).tearDown()
         self.delete_image(self.image.fingerprint)
 
-    def test_update(self):
+    def test_save(self):
         """The image properties are updated."""
         description = 'an description'
         self.image.properties['description'] = description
-        self.image.update()
+        self.image.save()
 
         image = self.client.images.get(self.image.fingerprint)
         self.assertEqual(description, image.properties['description'])
@@ -81,12 +81,12 @@ class TestImage(IntegrationTestCase):
         self.image.delete(wait=True)
 
         self.assertRaises(
-            exceptions.NotFound,
+            exceptions.LXDAPIException,
             self.client.images.get, self.image.fingerprint)
 
     def test_export(self):
-        """The imerage is successfully exported."""
-        data = self.image.export()
+        """The image is successfully exported."""
+        data = self.image.export().read()
         data_sha = hashlib.sha256(data).hexdigest()
 
         self.assertEqual(self.image.fingerprint, data_sha)
